@@ -1,4 +1,5 @@
 import csv
+import json
 import aiohttp
 import asyncio
 import hashlib
@@ -60,19 +61,19 @@ class WhisperQuery(object):
     async def __post(self, row: list, session=None) -> list:
         async with self.semaphore:
             async with session.post(self.url, json={"inputs": [row[0]]}) as response:
-                return row + [await response.json()]
+                return row + [json.dumps(await response.json(), ensure_ascii=False)]
 
 
 class NeteaseQuery(WhisperQuery):
 
-    def __init__(self, source_file: str, target_file: str, semaphore: int = 4):
+    def __init__(self, source_file: str, target_file: str, semaphore: int = 4, url: str = "localhost"):
         """Initial configuration
         url: serving url to request
         source_file: the file of query
         target_file: the file of results
         semaphore: maximum concurrency
         """
-        self.url = "http://172.26.230.4:1163/check"
+        self.url = "http://{}:1163/check".format(url)
         self.source_file = source_file
         self.target_file = target_file
         self.semaphore = asyncio.Semaphore(semaphore)
@@ -82,7 +83,7 @@ class NeteaseQuery(WhisperQuery):
     async def __post(self, row: list, session=None) -> list:
         async with self.semaphore:
             async with session.post(self.url, json={"dataId": self.get_md5(row[0]), "content": row[0]}) as response:
-                return row + [await response.json()]
+                return row + [await response.text()]
 
     def get_md5(self, s):
         md = hashlib.md5()
@@ -110,9 +111,9 @@ class NeteaseQuery(WhisperQuery):
             f_csv = csv.reader(f)
             rows.append(next(f_csv))
             for row in f_csv:
-                if row[index] == "{'msg': '调用API接口失败'}":
+                if r"\u8c03\u7528API\u63a5\u53e3\u5931\u8d25" in row[index]:
                     res = requests.post(self.url, json={"dataId": self.get_md5(row[0]), "content": row[0]})
-                    row[index] = res.json()
+                    row[index] = res.text
                 rows.append(row)
 
         with open(file, 'w', encoding='utf-8') as f:
